@@ -22,7 +22,7 @@ variable and set the C<HARNESS_BREAK> environment variable to a true value.
 
 =cut
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 
 =head2 $self->private_backend_plugins()
 
@@ -92,9 +92,9 @@ L<http://cpanratings.perl.org/d/Test::Run::Plugin::BreakOnFailure>
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test::Run::Plugin::BreakOnFailure>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Test-Run-Plugin-BreakOnFailure/>
+L<https://metacpan.org/release/Test-Run-Plugin-BreakOnFailure>
 
 =back
 
